<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-images?lang_cible=ru
// ** ne pas modifier le fichier **

return [

	// I
	'images_description' => 'Набор фильтров по работе с изображениями',
	'images_slogan' => 'Набор фильтров по работе с изображениями',
];
